@@ -1,4 +1,4 @@
-import time, os, stat, string
+import time, os, stat, string, tempfile
 from functools import wraps
 from shutil import which
 from random import random, SystemRandom
@@ -10,7 +10,7 @@ def file_age_in_seconds(pathname) -> float:
 
 def make_slug(inp: str) -> str:
     from slugify import slugify
-    return slugify(inp)
+    return slugify(inp, max_length=32)
 
 
 def program_exists(name: str):
@@ -43,3 +43,10 @@ def random_str(num_chars: int):
     return ''.join(
         SystemRandom().choice(
             string.ascii_uppercase + string.ascii_lowercase + string.digits) for _ in range(num_chars))
+
+
+def path_temp_name() -> str:
+    """generate temporary tmp path"""
+    temp_name = next(tempfile._get_candidate_names())
+    tmp_dir = tempfile._get_default_tempdir()
+    return f"{tmp_dir}/{temp_name}"
